summary refs log tree commit diff
path: root/pkgs/build-support
diff options
context:
space:
mode:
authorMatthew Bauer <mjbauer95@gmail.com>2019-03-04 16:12:41 -0500
committerGitHub <noreply@github.com>2019-03-04 16:12:41 -0500
commit71704e81293c4a21cc2c85b5b8eae89897dcb949 (patch)
tree03582d50b62ee11b50e59e9accade3f221e21a72 /pkgs/build-support
parentf274fc865628b8a994615e8149631829b7107871 (diff)
parentd17d18ad81c07af2646a631e9ed129c54871b7a7 (diff)
downloadnixpkgs-71704e81293c4a21cc2c85b5b8eae89897dcb949.tar
nixpkgs-71704e81293c4a21cc2c85b5b8eae89897dcb949.tar.gz
nixpkgs-71704e81293c4a21cc2c85b5b8eae89897dcb949.tar.bz2
nixpkgs-71704e81293c4a21cc2c85b5b8eae89897dcb949.tar.lz
nixpkgs-71704e81293c4a21cc2c85b5b8eae89897dcb949.tar.xz
nixpkgs-71704e81293c4a21cc2c85b5b8eae89897dcb949.tar.zst
nixpkgs-71704e81293c4a21cc2c85b5b8eae89897dcb949.zip
Merge pull request #55081 from moyamo/fix-subdirs.el
Link subdirs.el into emacs-packages-deps site-lisp
Diffstat (limited to 'pkgs/build-support')
-rw-r--r--pkgs/build-support/emacs/wrapper.nix12
1 files changed, 8 insertions, 4 deletions
diff --git a/pkgs/build-support/emacs/wrapper.nix b/pkgs/build-support/emacs/wrapper.nix
index e161daffbd3..dfdd5b60851 100644
--- a/pkgs/build-support/emacs/wrapper.nix
+++ b/pkgs/build-support/emacs/wrapper.nix
@@ -121,21 +121,25 @@ stdenv.mkDerivation {
 
      siteStart="$out/share/emacs/site-lisp/site-start.el"
      siteStartByteCompiled="$siteStart"c
+     subdirs="$out/share/emacs/site-lisp/subdirs.el"
+     subdirsByteCompiled="$subdirs"c
 
      # A dependency may have brought the original siteStart, delete it and
      # create our own
      # Begin the new site-start.el by loading the original, which sets some
      # NixOS-specific paths. Paths are searched in the reverse of the order
      # they are specified in, so user and system profile paths are searched last.
-     rm -f $siteStart $siteStartByteCompiled
+     rm -f $siteStart $siteStartByteCompiled $subdirs $subdirsByteCompiled
      cat >"$siteStart" <<EOF
 (load-file "$emacs/share/emacs/site-lisp/site-start.el")
 (add-to-list 'load-path "$out/share/emacs/site-lisp")
 (add-to-list 'exec-path "$out/bin")
 EOF
+      # Link subdirs.el from the emacs distribution
+      ln -s $emacs/share/emacs/site-lisp/subdirs.el -T $subdirs
 
      # Byte-compiling improves start-up time only slightly, but costs nothing.
-     $emacs/bin/emacs --batch -f batch-byte-compile "$siteStart"
+     $emacs/bin/emacs --batch -f batch-byte-compile "$siteStart" "$subdirs"
   '';
 
   phases = [ "installPhase" ];
@@ -121,21 +121,25 @@ stdenv.mkDerivation {
 
-     # A dependency may have brought the original siteStart, delete it and
-     # create our own
+     # A dependency may have brought the original siteStart or subdirs, delete
+     # it and create our own
      # Begin the new site-start.el by loading the original, which sets some
      # NixOS-specific paths. Paths are searched in the reverse of the order